function s = attitude_determination(t,x,paramSensor)


    
%% Gyro calibration
a11 = paramSensor.Gyro.a11;
a22 = paramSensor.Gyro.a22;
a33 = paramSensor.Gyro.a33;
a13 = paramSensor.Gyro.a13;
a32 = paramSensor.Gyro.a32;
a12 = paramSensor.Gyro.a12;
a1  = paramSensor.Gyro.a1;
a2  = paramSensor.Gyro.a2;
a3  = paramSensor.Gyro.a3;
sigmaGyro  = paramSensor.Gyro.sigmaNoise;

T13 = cos(a13);
T23 = cos(a32);
T22 = sin(a32);
T12 = (cos(a12)-T13*T23)/T22;
T11 = sqrt(1-T12^2-T13^2);
K = diag([a11 a22 a33]);
T = [T11 T12 T13; 0 T22 T23; 0 0 1];
A = K*T;

%% IMU calibration
b11 = paramSensor.IMU.a11;
b22 = paramSensor.IMU.a22;
b33 = paramSensor.IMU.a33;
b13 = paramSensor.IMU.a13;
b32 = paramSensor.IMU.a32;
b12 = paramSensor.IMU.a12;
b1  = paramSensor.IMU.a1;
b2  = paramSensor.IMU.a2;
b3  = paramSensor.IMU.a3;
sigmaIMU  = paramSensor.IMU.sigmaNoise;

T13 = cos(b13);
T23 = cos(b32);
T22 = sin(b32);
T12 = (cos(b12)-T13*T23)/T22;
T11 = sqrt(1-T12^2-T13^2);
K = diag([b11 b22 b33]);
T = [T11 T12 T13; 0 T22 T23; 0 0 1];
B = K*T;


%% Perform measurement

for iT = 1:numel(t)
    
    yaw   = x(iT,1);
    pitch = x(iT,2);
    roll  = x(iT,3);
    w     = x(iT,4:6);
    
    Q = [cos(yaw)*cos(pitch) cos(yaw)*sin(pitch)*sin(roll)-sin(yaw)*cos(roll) cos(yaw)*sin(pitch)*cos(roll)+sin(yaw)*sin(roll); ...
         sin(yaw)*cos(pitch) sin(yaw)*sin(pitch)*sin(roll)+cos(yaw)*cos(roll) sin(yaw)*sin(pitch)*cos(roll)-cos(yaw)*sin(roll); ...
         -sin(pitch)         cos(pitch)*sin(roll)                             cos(pitch)*cos(roll)                           ];

    % Esitmate noisy tilt -------------------------------------------------
    % real value of g
    g = Q'*[0 0 -9.81]';
    % add sensor noise
    gn = g + randn(3,1)*sigmaIMU;
    % add calibration
    gnx = B(1,1)*gn(1) + B(1,2)*gn(2) + B(1,3)*gn(3) + b1;
    gny = B(2,2)*gn(2) + B(2,3)*gn(3) + b2;
    gnz = B(3,3)*gn(3) + b3;
    % normalization 
    gn = [gnx, gny, gnz]'; ug = gn/norm(gn);
    
 
    pitchn = atan2(-ug(1),sqrt(ug(2)^2+ug(3)^2));
    rolln  = atan2(ug(2),ug(3));
    % ---------------------------------------------------------------------
    % Estimate noisy omegas
    wn  = w' + randn(3,1)*sigmaGyro;
    wxn = A(1,1)*wn(1) + A(1,2)*wn(2) + A(1,3)*wn(3) + a1;
    wyn = A(2,2)*wn(2) + A(2,3)*wn(3) + a2;
    wzn = A(3,3)*wn(3) + a3;
    
    s(iT,1) = pitchn;
    s(iT,2) = rolln;
    s(iT,3) = wxn;
    s(iT,4) = wyn;
    s(iT,5) = wzn;
    
end

    

