function xdot=euler_equations_RPY(t,x,J_SC,M_SC,RG_SC)

%Euler 1-2-3 kinematics of a rigid body
%x(1)=omega_x, x(2)=omega_y, x(3)=omega_z (angular velocity in rad/s)
%x(4)=phi(yaw), x(5)=theta(pitch), x(6)=psi(roll) (rad)

yaw   = x(1);
pitch = x(2);
roll  = x(3);
omega_x = x(4);
omega_y = x(5);
omega_z = x(6);
w = [omega_x, omega_y, omega_z]';

Q = [cos(yaw)*cos(pitch) cos(yaw)*sin(pitch)*sin(roll)-sin(yaw)*cos(roll) cos(yaw)*sin(pitch)*cos(roll)+sin(yaw)*sin(roll); ...
     sin(yaw)*cos(pitch) sin(yaw)*sin(pitch)*sin(roll)+cos(yaw)*cos(roll) sin(yaw)*sin(pitch)*cos(roll)-cos(yaw)*sin(roll); ...
     -sin(pitch)         cos(pitch)*sin(roll)                             cos(pitch)*cos(roll)                           ];

gb = Q'*[0 0 -9.81]';
T  = M_SC*cross(RG_SC,gb);

xdot(1,1)=1/cos(pitch)*(sin(roll)*omega_y+cos(roll)*omega_z);
xdot(2,1)=omega_y*cos(roll)-omega_z*sin(roll);
xdot(3,1)=omega_x+omega_y*tan(pitch)*sin(roll)+omega_z*tan(pitch)*cos(roll);
xdot(4:6,1) = J_SC\(T-cross(w,J_SC*w));
